@@ -241,9 +241,10 @@ def test_special_characters_in_dn(name, udm_client, udm_rest):
     assert obj
 
 
+@locale_available()
 @pytest.mark.parametrize('language,error_message', [
-    pytest.param('en-US', 'The property gecos has an invalid value: GECOS: Field must only contain ASCII characters!', marks=locale_available("en_US")),
-    pytest.param('de-DE', 'Die Eigenschaft gecos hat einen ungültigen Wert: GECOS: Der Wert darf nur ASCII Buchstaben enthalten!', marks=locale_available("de_DE")),
+    ('en-US', 'The property gecos has an invalid value: GECOS: Field must only contain ASCII characters!'),
+    ('de-DE', 'Die Eigenschaft gecos hat einen ungültigen Wert: GECOS: Der Wert darf nur ASCII Buchstaben enthalten!'),
 ])
 def test_translation(language, error_message):
     with UDM(language=language) as udm:
