@@ -11,17 +11,23 @@ import base64
 import json
 import os
 import uuid
-from types import SimpleNamespace
+from typing import TYPE_CHECKING
 
 import pytest
-from keycloak import KeycloakAdmin
 from keycloak.exceptions import KeycloakError, KeycloakGetError
 from playwright.sync_api import expect
 from utils import get_portal_tile, keycloak_login, run_command
 
-from univention.config_registry.backend import ConfigRegistry
 from univention.udm import UDM
-from univention.udm.modules.users_user import UsersUserObject
+
+
+if TYPE_CHECKING:
+    from types import SimpleNamespace
+
+    from keycloak import KeycloakAdmin
+
+    from univention.config_registry.backend import ConfigRegistry
+    from univention.udm.modules.users_user import UsersUserObject
 
 
 def get_realm_payload(realm: str, locales_format: str, default_locale: str, keycloak_url: str) -> dict:
